==> mariadb-5.5.67.tar.gz: mariadb-5.5.67/storage/ndb/src/cw/cpcc-win32/C++/resource.h <==
/* Copyright (c) 2003, 2005 MySQL AB
   Use is subject to license terms

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1335  USA */

//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by CPC_GUI.rc
//
#define IDC_MYICON                      2
#define IDD_CPC_GUI_DIALOG              102
#define IDD_ABOUTBOX                    103
#define IDS_APP_TITLE                   103
#define IDM_ABOUT                       104
#define IDS_LV_ROOT_COMPUTERS           104
#define IDS_TV_ROOT_COMPUTERS           104
#define IDM_EXIT                        105
#define IDS_LV_ROOT_DATABASES           105
#define IDS_TV_ROOT_DATABASES           105
#define IDS_HELLO                       106
#define IDS_LV_COMPUTER_HEADER_1        106
#define IDI_CPC_GUI                     107
#define IDS_LV_COMPUTER_HEADER_2        107
#define IDI_SMALL                       108
#define IDS_LV_PROCESS_HEADER_1         108
#define IDC_CPC_GUI                     109
#define IDM_CPC_GUI                     109
#define IDS_TIP_NEW                     110
#define IDS_TIP_DELETE                  111
#define IDS_TIP_PROPS                   112
#define IDS_LV_PROCESS_HEADER_2         113
#define IDS_LV_PROCESS_HEADER_3         114
#define IDS_LV_PROCESS_HEADER_4         115
#define IDS_LV_COMPUTER_HEADER_3        116
#define IDR_MAINFRAME                   128
#define ID_TREEVIEW                     130
#define IDM_TREEVIEW                    130
#define IDB_TOOLBAR                     137
#define ID_TOOLBAR                      158
#define IDB_COMPUTER                    168
#define IDB_CLOSED                      169
#define IDB_OPEN                        170
#define IDI_DATABASE                    172
#define IDI_CLOSED                      175
#define IDI_OPEN                        176
#define IDI_COMPUTER                    177
#define IDB_MASK                        178
#define IDB_DATABASE                    182
#define IDM_TV                          183
#define ID_TREEVIEW1                    32771
#define ID_BUTTON32773                  32773
#define IDM_NEW                         32774
#define IDM_DELETE                      32775
#define IDM_PROPS                       32776
#define ID_LIST_C                       32777
#define ID_ACTIONS_INSERT               32778
#define ID_ACTIONS_DELETE               32779
#define ID_DELETE                       32780
#define ID_PROPERTIES                   32781
#define ID_ACTIONS_PROPERTIES           32782
#define ID_BUTTON32783                  32783
#define ID_BUTTON32784                  32784
#define ID_LIST_P                       32785
#define ID_STATUSBAR                    32786
#define ID_LIST_C_ROOT                  32787
#define ID_LIST_D_ROOT                  32788
#define IDM_ADDNEW                      32793
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        184
#define _APS_NEXT_COMMAND_VALUE         32796
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif

==> mariadb-10.0.9.tar.gz: mariadb-10.0.9/storage/ndb/src/cw/cpcc-win32/C++/resource.h <==
/* Copyright (c) 2003, 2005 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */

//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by CPC_GUI.rc
//
#define IDC_MYICON                      2
#define IDD_CPC_GUI_DIALOG              102
#define IDD_ABOUTBOX                    103
#define IDS_APP_TITLE                   103
#define IDM_ABOUT                       104
#define IDS_LV_ROOT_COMPUTERS           104
#define IDS_TV_ROOT_COMPUTERS           104
#define IDM_EXIT                        105
#define IDS_LV_ROOT_DATABASES           105
#define IDS_TV_ROOT_DATABASES           105
#define IDS_HELLO                       106
#define IDS_LV_COMPUTER_HEADER_1        106
#define IDI_CPC_GUI                     107
#define IDS_LV_COMPUTER_HEADER_2        107
#define IDI_SMALL                       108
#define IDS_LV_PROCESS_HEADER_1         108
#define IDC_CPC_GUI                     109
#define IDM_CPC_GUI                     109
#define IDS_TIP_NEW                     110
#define IDS_TIP_DELETE                  111
#define IDS_TIP_PROPS                   112
#define IDS_LV_PROCESS_HEADER_2         113
#define IDS_LV_PROCESS_HEADER_3         114
#define IDS_LV_PROCESS_HEADER_4         115
#define IDS_LV_COMPUTER_HEADER_3        116
#define IDR_MAINFRAME                   128
#define ID_TREEVIEW                     130
#define IDM_TREEVIEW                    130
#define IDB_TOOLBAR                     137
#define ID_TOOLBAR                      158
#define IDB_COMPUTER                    168
#define IDB_CLOSED                      169
#define IDB_OPEN                        170
#define IDI_DATABASE                    172
#define IDI_CLOSED                      175
#define IDI_OPEN                        176
#define IDI_COMPUTER                    177
#define IDB_MASK                        178
#define IDB_DATABASE                    182
#define IDM_TV                          183
#define ID_TREEVIEW1                    32771
#define ID_BUTTON32773                  32773
#define IDM_NEW                         32774
#define IDM_DELETE                      32775
#define IDM_PROPS                       32776
#define ID_LIST_C                       32777
#define ID_ACTIONS_INSERT               32778
#define ID_ACTIONS_DELETE               32779
#define ID_DELETE                       32780
#define ID_PROPERTIES                   32781
#define ID_ACTIONS_PROPERTIES           32782
#define ID_BUTTON32783                  32783
#define ID_BUTTON32784                  32784
#define ID_LIST_P                       32785
#define ID_STATUSBAR                    32786
#define ID_LIST_C_ROOT                  32787
#define ID_LIST_D_ROOT                  32788
#define IDM_ADDNEW                      32793
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        184
#define _APS_NEXT_COMMAND_VALUE         32796
#define _APS_NEXT_CONTROL_VALUE         1000
#define _APS_NEXT_SYMED_VALUE           110
#endif
#endif
